@@ -19,13 +19,15 @@ def disconnect():
     disconnectSerial()
 
 def executeCommand(pump, command, waitForPump=False):
-    sendCommand(pump.asciiAddress, command, waitForPump)
+    if pump.checkValidity(command):
+        sendCommand(pump.asciiAddress, command, waitForPump)
+        pump.command.resetInternalParams()
 
 def definePump(address: str, type: util.PSDTypes, baudRate=9600, resolutionMode=0):
     if len(pumps) < pumpLength:
         newPump = PSD(address, type, baudRate, resolutionMode)
         print("Enable h Factor Commands and Queries")
-        sendCommand(newPump.asciiAddress, newPump.command.hEnableFactorCommands(True) + newPump.command.executeCommandBuffer())
+        sendCommand(newPump.asciiAddress, newPump.command.enableFactorCommands(True) + newPump.command.executeCommandBuffer())
         result = sendCommand(newPump.asciiAddress, newPump.command.syringeModeQuery(), True)
         resolution = result[3:4]
         newPump.setResolution(int(resolution))
