@@ -1,4 +1,3 @@
-#from util import *
 from .command import *
 
 
@@ -7,23 +6,19 @@ class CommandPSD4(Command):
         super().__init__(type)
         self.resolution_mode = 0
 
-    def hSetSyringeMode(self, mode: int):
-        cmd = super().hSetSyringeMode(mode)
+    def setSyringeMode(self, mode: int):
+        cmd = super().setSyringeMode(mode)
         if mode == 0 or mode == 1:
             self.resolution_mode = mode
-        print("set syringe mode for PSD 4")
-        print("new resolutin mode =" + str(mode))
         return cmd
 
     def absolutePosition(self, value: int):
         # absolute position x where 0 ≤ x ≤ 3,000 in standard mode or 0 ≤ x ≤ 24,000 in high resolution mode
         bResult = False
         cmd: str = 'A'
-        print("received absolute position value: " + str(value))
 
         if self.checkValueInInterval(value, 3000, 24000):
             cmd += str(value)
-            print("Correct PSD4 absolute position command!")
         else:
             print("Wrong parameter value PSD4 for absolute position command!")
             cmd = 'cmdError'
@@ -34,7 +29,6 @@ class CommandPSD4(Command):
         cmd: str = 'a'
         if self.checkValueInInterval(value, 3000, 24000):
             cmd += str(value)
-            print("Correct PSD4 absolute position command!")
         else:
             print("Wrong parameter value PSD4 for absolute position with ready status command!")
             cmd = 'cmdError'
@@ -103,7 +97,7 @@ class CommandPSD4(Command):
     """
         Motor Commands
     """
-    def mStandardHighResolutionSelection(self, mode: int):
+    def standardHighResolutionSelection(self, mode: int):
         # x=0 for standard resolution mode
         # x=1 for high resolution mode
         cmd: str = 'N'
@@ -116,7 +110,7 @@ class CommandPSD4(Command):
             print("Wrong parameter value for standard/high resolution selection command!")
         return cmd
 
-    def mSetStartVelocity(self, value: int):
+    def setStartVelocity(self, value: int):
         cmd: str = 'v'
         if 50 <= value <= 1000:
             cmd += str(value)
@@ -125,7 +119,7 @@ class CommandPSD4(Command):
             print("Wrong parameter value for set start velocity command!")
         return cmd
 
-    def mSetMaximumVelocity(self, value: int):
+    def setMaximumVelocity(self, value: int):
         cmd: str = 'V'
         if 2 <= value <= 5800:
             cmd += str(value)
@@ -134,7 +128,7 @@ class CommandPSD4(Command):
             print("Wrong parameter value for set maximum velocity command!")
         return cmd
 
-    def mStopVelocity(self, value: int):
+    def stopVelocity(self, value: int):
         cmd: str = 'c'
         if 50 <= value <= 2700:
             cmd += str(value)
@@ -145,7 +139,6 @@ class CommandPSD4(Command):
 
     def checkValueInInterval(self, value: int, valueST: int, valueHG: int):
         bVal: bool = False
-        print("Resolution mode is: " + str(self.resolution_mode))
         # if standard mode
         if self.resolution_mode == 0 and 0 <= value <= valueST:
             bVal = True
