@@ -90,6 +90,9 @@ class PSD:
                 print("basic command")
                 type = type | 0b0001
 
+        if type == 0b0111 or type == 0b0011 or type == 0b0110 or type == 0b0101:
+            print("Error! Composed commands are not allowed!")
+
         return type
 
     def checkValidity(self, command: str):
@@ -101,6 +104,8 @@ class PSD:
             if (commandType == 0b0010 or commandType == 0b0100 or commandType == 0b0001) and \
                     self.checkGgPairs(self.command.command_g_counter, self.command.command_G_counter):
                 result = True
+            else:
+                print()
         else:
             print("Error! Wrong command! Check manual!")
 
@@ -114,6 +119,6 @@ class PSD:
         if G_count == g_count or G_count == temp + 1:
             result = True
         else:
-            print("Error!Inconsistent pair of g-G!")
+            print("Error! Inconsistent pair of g-G!")
 
         return result
\ No newline at end of file
